i_is_index Tests if x fit the requirements of being indices
i_is_index(x, max_value, allow_negative = FALSE)numeric values
boolean. Count negative integers as indices? defaults to FALSE
Max acceptable values for x (inclusive). Must be >= 1
boolean
This function potentially allows negative indices, given that they may be used with the intent of removing an entry that corresponds to the index. Conversely, zero is never used as an index in R and is not recognized as such here.