i_names: Internal constructor for sample names
Description
i_names constructs a sample name vector in the appropriate format
Usage
i_names(x, nsample = NULL, prefix = "spec_")
Arguments
x
vector of labels. Should be character. If numeric, a prefix will be added
nsample
Integer of expected number of samples.
If NULL (default) checking is skipped.
prefix
String to use as prefix in case an element of x is numeric.
Defaults to "spec_"
Value
vector of sample names coerced to character