Generic parser for SVC's `.sig` and PSR's `.sed`
i_read_ascii_spectra(
file_paths,
skip_until_tag = NULL,
skip_first_n = NULL,
sep_char,
header,
wl_col,
refl_cols,
divide_refl_by,
...
)paths for files already parsed by `read_spectra`
Tag that precedes the table of value data, indicating that lines until that tag should be skipped. Tag is matched with a regexpr.
skip the first n lines. Only used if `skip_until_tag` is not given
separator
boolean. keep header?
idx or name of band column
idx or name of value columns. MULTIPLE
divide values by this. MULTIPLE
additional arguments passed to read table
single `spectra` or list of `spectra`