powered by
Read files from various formats into `spectra`
read_spectra( path, format, type = "target_reflectance", recursive = FALSE, exclude_if_matches = NULL, ignore_extension = FALSE, ... )
Path to directory or input files
file formats. "asd" (for ASD); "sig" or "svc" (for SVC); "sed" or "psr" (for SpecEvo PSR).
Data type to read. "target_reflectance", "target_radiance", or "reference_radiance". Defaults to "target_reflectance".
read files recursively
excludes files that match this regular expression. Example: "BAD"
boolean. If TRUE, the parser will try to read every file in path regardless of the expected extension.
nothing yet
a single `spectra` or a list of `spectra` (in case files have incompatible band number or bands values)
# NOT RUN { library(spectrolab) dir_path = system.file("extdata", "Acer_example", package = "spectrolab") # Relative reflectance is re spec = read_spectra(path = dir_path, format = "sig") # }
Run the code above in your browser using DataLab